@@ -108,12 +108,10 @@ static const BindAction window_actions[] = {
 	{ EPHY_PREFS_LOCKDOWN_PRINT_SETUP, "FilePrintSetup", "sensitive" },
 	{ EPHY_PREFS_LOCKDOWN_COMMAND_LINE, "FilePrintSetup", "sensitive" },
 
-	{ EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING, "GoBookmarks", "sensitive" },
 	{ EPHY_PREFS_LOCKDOWN_BOOKMARK_EDITING, "FileBookmarkPage", "sensitive" },
 
 	{ EPHY_PREFS_LOCKDOWN_ARBITRARY_URL, "GoLocation", "sensitive" },
 	{ EPHY_PREFS_LOCKDOWN_SAVE_TO_DISK, "FileSaveAs", "sensitive" },
-	{ EPHY_PREFS_LOCKDOWN_HISTORY, "GoHistory", "sensitive" },
 
 	{ EPHY_PREFS_LOCKDOWN_FULLSCREEN, "ViewFullscreen", "sensitive" },
 	{ EPHY_PREFS_LOCKDOWN_FULLSCREEN, "TabsDetach", "sensitive" }
@@ -129,14 +127,11 @@ static const BindAction popup_actions[] = {
 
 static const BindAction special_toolbar_actions[] = {
 	{ EPHY_PREFS_LOCKDOWN_ARBITRARY_URL, "Location", "editable" },
-	{ EPHY_PREFS_LOCKDOWN_ARBITRARY_URL, "NavigationUp", "sensitive" },
 
 	{ EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationBack", "visible" },
 	{ EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationBack", "sensitive" },
 	{ EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationForward", "visible" },
 	{ EPHY_PREFS_LOCKDOWN_HISTORY, "NavigationForward", "sensitive" },
-
-	{ EPHY_PREFS_LOCKDOWN_FULLSCREEN, "FileNewWindow", "sensitive" }
 };
 
 static gboolean
@@ -228,11 +223,6 @@ impl_attach_window (EphyExtension *extension,
 				   action_group, window_actions,
 				   G_N_ELEMENTS (window_actions));
 
-	action = gtk_action_group_get_action (action_group, "ViewToolbar");
-	g_settings_bind_writable (EPHY_SETTINGS_UI,
-				  EPHY_PREFS_UI_SHOW_TOOLBARS,
-				  action, "sensitive", FALSE);
-
 	action_group = find_action_group (manager, "PopupsActions");
 	bind_settings_and_actions (EPHY_SETTINGS_LOCKDOWN,
 				   action_group, popup_actions,
